BrainPack

Struct BrainPack 

pub struct BrainPack { /* private fields */ }

Implementations

Source

impl BrainPack

pub fn new(runtime: KhiveRuntime) -> Self

pub fn snapshot(&self) -> BrainStateSnapshot

Public snapshot of the current BrainState.

Equivalent to dispatching the brain.state verb but callable directly when you hold an Arc<BrainPack> (e.g. a test that registered the pack as a DispatchHook and wants to verify posteriors updated).